@@ -39,10 +39,9 @@ XRRGetCrtcInfo (Display *dpy, XRRScreenResources *resources, RRCrtc crtc)
     xRRGetCrtcInfoReply	    rep;
     xRRGetCrtcInfoReq	    *req;
     int			    nbytes, nbytesRead, rbytes;
-    int			    i;
     XRRCrtcInfo		    *xci;
 
-    RRCheckExtension (dpy, info, 0);
+    RRCheckExtension (dpy, info, NULL);
 
     LockDisplay (dpy);
     GetReq (RRGetCrtcInfo, req);
@@ -63,8 +62,8 @@ XRRGetCrtcInfo (Display *dpy, XRRScreenResources *resources, RRCrtc crtc)
     nbytesRead = (long) (rep.nOutput * 4 +
 			 rep.nPossibleOutput * 4);
 
-    /* 
-     * first we must compute how much space to allocate for 
+    /*
+     * first we must compute how much space to allocate for
      * randr library's use; we'll allocate the structures in a single
      * allocation, on cleanlyness grounds.
      */
@@ -96,13 +95,13 @@ XRRGetCrtcInfo (Display *dpy, XRRScreenResources *resources, RRCrtc crtc)
 
     _XRead32 (dpy, xci->outputs, rep.nOutput << 2);
     _XRead32 (dpy, xci->possible, rep.nPossibleOutput << 2);
-    
+
     /*
      * Skip any extra data
      */
     if (nbytes > nbytesRead)
 	_XEatData (dpy, (unsigned long) (nbytes - nbytesRead));
-    
+
     UnlockDisplay (dpy);
     SyncHandle ();
     return (XRRCrtcInfo *) xci;
@@ -128,7 +127,6 @@ XRRSetCrtcConfig (Display *dpy,
     XExtDisplayInfo	    *info = XRRFindDisplay(dpy);
     xRRSetCrtcConfigReply   rep;
     xRRSetCrtcConfigReq	    *req;
-    int			    i;
 
     RRCheckExtension (dpy, info, 0);
 
@@ -159,7 +157,6 @@ XRRGetCrtcGammaSize (Display *dpy, RRCrtc crtc)
     XExtDisplayInfo		*info = XRRFindDisplay(dpy);
     xRRGetCrtcGammaSizeReply	rep;
     xRRGetCrtcGammaSizeReq	*req;
-    int				i;
 
     RRCheckExtension (dpy, info, 0);
 
@@ -170,7 +167,7 @@ XRRGetCrtcGammaSize (Display *dpy, RRCrtc crtc)
     req->crtc = crtc;
 
     if (!_XReply (dpy, (xReply *) &rep, 0, xFalse))
-	rep.status = RRSetConfigFailed;
+	rep.size = 0;
     UnlockDisplay (dpy);
     SyncHandle ();
     return rep.size;
@@ -182,12 +179,11 @@ XRRGetCrtcGamma (Display *dpy, RRCrtc crtc)
     XExtDisplayInfo	    *info = XRRFindDisplay(dpy);
     xRRGetCrtcGammaReply    rep;
     xRRGetCrtcGammaReq	    *req;
-    int			    i;
-    XRRCrtcGamma	    *crtc_gamma;
+    XRRCrtcGamma	    *crtc_gamma = NULL;
     long    		    nbytes;
     long    		    nbytesRead;
 
-    RRCheckExtension (dpy, info, 0);
+    RRCheckExtension (dpy, info, NULL);
 
     LockDisplay(dpy);
     GetReq (RRGetCrtcGamma, req);
@@ -196,29 +192,28 @@ XRRGetCrtcGamma (Display *dpy, RRCrtc crtc)
     req->crtc = crtc;
 
     if (!_XReply (dpy, (xReply *) &rep, 0, xFalse))
-	rep.status = RRSetConfigFailed;
+	goto out;
 
     nbytes = (long) rep.length << 2;
-    
+
     /* three channels of CARD16 data */
     nbytesRead = (rep.size * 2 * 3);
 
     crtc_gamma = XRRAllocGamma (rep.size);
-    
+
     if (!crtc_gamma)
     {
 	_XEatData (dpy, (unsigned long) nbytes);
-	UnlockDisplay (dpy);
-	SyncHandle ();
-	return NULL;
+	goto out;
     }
     _XRead16 (dpy, crtc_gamma->red, rep.size * 2);
     _XRead16 (dpy, crtc_gamma->green, rep.size * 2);
     _XRead16 (dpy, crtc_gamma->blue, rep.size * 2);
-    
+
     if (nbytes > nbytesRead)
 	_XEatData (dpy, (unsigned long) (nbytes - nbytesRead));
-    
+
+out:
     UnlockDisplay (dpy);
     SyncHandle ();
     return crtc_gamma;
@@ -260,7 +255,7 @@ XRRSetCrtcGamma (Display *dpy, RRCrtc crtc, XRRCrtcGamma *crtc_gamma)
      * otherwise the channels might not be contiguous
      */
     Data16 (dpy, crtc_gamma->red, crtc_gamma->size * 2 * 3);
-    
+
     UnlockDisplay (dpy);
     SyncHandle ();
 }
@@ -309,7 +304,7 @@ xRenderTransform_from_XTransform (xRenderTransform *render,
 
 void
 XRRSetCrtcTransform (Display	*dpy,
-		     RRCrtc	crtc, 
+		     RRCrtc	crtc,
 		     XTransform	*transform,
 		     char	*filter,
 		     XFixed	*params,
@@ -339,7 +334,7 @@ XRRSetCrtcTransform (Display	*dpy,
 }
 
 #define CrtcTransformExtra	(SIZEOF(xRRGetCrtcTransformReply) - 32)
-				
+
 static const xRenderTransform identity = {
     0x10000, 0, 0,
     0, 0x10000, 0,
@@ -358,7 +353,6 @@ XRRGetCrtcTransform (Display	*dpy,
 		     XRRCrtcTransformAttributes **attributes)
 {
     XExtDisplayInfo		*info = XRRFindDisplay(dpy);
-    XRandRInfo			*xrri;
     xRRGetCrtcTransformReply	rep;
     xRRGetCrtcTransformReq	*req;
     int				major_version, minor_version;
@@ -370,7 +364,7 @@ XRRGetCrtcTransform (Display	*dpy,
 
     RRCheckExtension (dpy, info, False);
 
-    if (!XRRQueryVersion (dpy, &major_version, &minor_version) || 
+    if (!XRRQueryVersion (dpy, &major_version, &minor_version) ||
 	!_XRRHasTransform (major_version, minor_version))
     {
 	/* For pre-1.3 servers, just report identity matrices everywhere */
@@ -388,7 +382,7 @@ XRRGetCrtcTransform (Display	*dpy,
 	req->reqType = info->codes->major_opcode;
 	req->randrReqType = X_RRGetCrtcTransform;
 	req->crtc = crtc;
-    
+
 	if (!_XReply (dpy, (xReply *) &rep, CrtcTransformExtra >> 2, xFalse))
 	{
 	    rep.pendingTransform = identity;
@@ -472,7 +466,7 @@ XRRGetPanning (Display *dpy, XRRScreenResources *resources, RRCrtc crtc)
     xRRGetPanningReq	    *req;
     XRRPanning		    *xp;
 
-    RRCheckExtension (dpy, info, 0);
+    RRCheckExtension (dpy, info, NULL);
 
     LockDisplay (dpy);
     GetReq (RRGetPanning, req);
@@ -528,7 +522,6 @@ XRRSetPanning (Display *dpy,
     XExtDisplayInfo	    *info = XRRFindDisplay(dpy);
     xRRSetPanningReply      rep;
     xRRSetPanningReq	    *req;
-    int			    i;
 
     RRCheckExtension (dpy, info, 0);
 
